MatchMakerMonitoring.on_exp_access() — alfred3_interact

Skip to main content
`Ctrl`+`K`

# MatchMakerMonitoring.on_exp_access()

MatchMakerMonitoring.on_exp_access()

  Executed once, when the `ExperimentSession` becomes available to the page.

  This is your go-to-hook, if you want to have access to the experiment, but don’t need access to data from other pages.

  See also

  See “How to use hooks” for a how to on using hooks and an overview of available hooks.